@@ -4,7 +4,7 @@
 #   include	<stdio.h>
 #   include	<appDebugon.h>
 
-#   define	LIST_PARA_STRING	1
+#   define	LIST_PARA_STRING	0
 #   define	LIST_PARTICULES		1
 #   define	LIST_FIRST_LINE		0
 #   define	LIST_LINES		0
@@ -97,25 +97,92 @@ static int docCheckChild(	const BufferItem *	parent,
 	rval= -1;
 	}
 
+    if  ( child->biLevel == DOClevPARA )
+	{
+	const BufferItem *	rowBi= child;
+
+	while( rowBi && rowBi->biLevel != DOClevROW )
+	    { rowBi= rowBi->biParent; }
+
+	if  ( ! rowBi )
+	    { SXDEB("#######",rowBi); rval= -1; }
+	else{
+	    if  ( child->biParaInTable != rowBi->biRowHasTableParagraphs )
+		{
+		SDEB("#######");
+		LLDEB(child->biParaInTable,rowBi->biRowHasTableParagraphs);
+		rval= -1;
+		}
+	    }
+	}
+
     if  ( lpBelow )
 	{ *lpBelow= child->biBelowPosition;	}
 
     return rval;
     }
 
-int docCheckItem(		const BufferItem *	bi )
+int docCheckItem(	const BufferItem *	bi )
     {
     int			i;
     int			rval= 0;
 
     if  ( bi->biLevel == DOClevPARA )
 	{
+	const BufferItem *	rowBi;
+
 	if  ( bi->biLeftParagraphs != bi->biNumberInParent+ 1 )
 	    {
 	    appDebug( "############## %s:\n",
-				    docLevelStr(bi->biLevel) );
+					docLevelStr(bi->biLevel) );
 	    LLDEB(bi->biLeftParagraphs,bi->biNumberInParent+1);
 	    }
+
+	rowBi= bi;
+	while( rowBi && rowBi->biLevel != DOClevROW )
+	    { rowBi= rowBi->biParent; }
+
+	if  ( ! rowBi )
+	    {
+	    appDebug( "############## %s:\n",
+					docLevelStr(bi->biLevel) );
+	    XDEB(rowBi);
+	    }
+	else{
+	    if  ( rowBi->biRowHasTableParagraphs != bi->biParaInTable )
+		{
+		appDebug( "############## %s:\n",
+					docLevelStr(bi->biLevel) );
+		LLDEB(rowBi->biRowHasTableParagraphs,bi->biParaInTable);
+		}
+	    }
+	}
+
+    if  ( bi->biLevel == DOClevROW )
+	{
+	if  ( bi->biRowHasTableParagraphs )
+	    {
+	    if  ( bi->biRowCellCount <= 0 )
+		{
+		appDebug( "############## %s:\n",
+					docLevelStr(bi->biLevel) );
+		LLDEB(bi->biRowHasTableParagraphs,bi->biRowCellCount);
+		}
+	    if  ( bi->biRowCellCount != bi->biChildCount )
+		{
+		appDebug( "############## %s:\n",
+					docLevelStr(bi->biLevel) );
+		LLDEB(bi->biRowCellCount,bi->biChildCount);
+		}
+	    }
+	else{
+	    if  ( bi->biRowCellCount != 0 )
+		{
+		appDebug( "############## %s:\n",
+					docLevelStr(bi->biLevel) );
+		LLDEB(bi->biRowHasTableParagraphs,bi->biRowCellCount);
+		}
+	    }
 	}
 
     if  ( bi->biChildCount > 0 )
@@ -152,6 +219,7 @@ int docCheckItem(		const BufferItem *	bi )
 	if  ( docCheckChild( bi, bi->biChildren[i], i,
 				(LayoutPosition *)0, (LayoutPosition *)0 ) )
 	    { rval= -1;	}
+
 	if  ( docCheckItem( bi->biChildren[i] ) )
 	    { rval= -1;	}
 	}
@@ -224,9 +292,10 @@ void docListItem(	int			indent,
 	    break;
 
 	case DOClevROW:
-	    appDebug( "%*s{ %4d children %d cells\n", indent+ 4, "",
-						bi->biChildCount,
-						bi->biRowCellCount );
+	    appDebug( "%*s{ %s %4d children %d cells\n", indent+ 4, "",
+				bi->biRowHasTableParagraphs?"T:":"--",
+				bi->biChildCount,
+				bi->biRowCellCount );
 
 	    docListChildren( indent, bi );
 
@@ -291,17 +360,19 @@ const char * docKindStr( int kind )
 
     switch( kind )
 	{
-	case DOCkindTEXT:	return "txt";
-	case DOCkindTAB:	return "TAB";
-	case DOCkindOBJECT:	return "OBJ";
-	case DOCkindFIELDSTART:	return "FLS";
-	case DOCkindFIELDEND:	return "FLE";
-	case DOCkindNOTE:	return "NOT";
-	case DOCkindXE:		return "XE ";
-	case DOCkindTC:		return "TC ";
-	case DOCkindLINEBREAK:	return "LIN";
-	case DOCkindPAGEBREAK:	return "PAG";
-	case DOCkindCHFTNSEP:	return "SEP";
+	case DOCkindTEXT:		return "txt";
+	case DOCkindTAB:		return "TAB";
+	case DOCkindOBJECT:		return "OBJ";
+	case DOCkindFIELDSTART:		return "FLS";
+	case DOCkindFIELDEND:		return "FLE";
+	case DOCkindNOTE:		return "NOT";
+	case DOCkindXE:			return "XE ";
+	case DOCkindTC:			return "TC ";
+	case DOCkindLINEBREAK:		return "LIN";
+	case DOCkindPAGEBREAK:		return "PAG";
+	case DOCkindCOLUMNBREAK:	return "COL";
+	case DOCkindCHFTNSEP:		return "SEP";
+	case DOCkindCHFTNSEPC:		return "SEC";
 
 	default:
 	    sprintf( scratch, "%3d", kind );
@@ -496,6 +567,9 @@ void docListNotes(	const BufferDocument *	bd )
     dn= bd->bdNotes;
     for ( i= 0; i < bd->bdNoteCount; dn++, i++ )
 	{
+	if  ( dn->dnParaNr < 0 )
+	    { appDebug( "deleted\n" ); continue; }
+
 	appDebug( "%-8s %3d: NR=%3d PG=%3d SECT=%2d PARA=%3d STROFF=%3d\n",
 	    docExternalKindStr( dn->dnExternalItemKind ),
 	    i, dn->dnNoteNumber,
