@@ -8,7 +8,7 @@
 #   define	DOC_STYLE_SHEET_H
 
 #   include	<utilPropMask.h>
-#   include	<docFont.h>
+#   include	<utilDocFont.h>
 
 #   include	"docSectProperties.h"
 #   include	"docParaProperties.h"
@@ -30,6 +30,7 @@ typedef struct DocumentStyle
     int			dsLevel;
     int			dsAutoupd;
     int			dsHidden;
+    int			dsSemiHidden;
     int			dsPersonal;
     int			dsBusy;
 
@@ -52,6 +53,7 @@ typedef enum DocumentStyleProperty
     DSpropLEVEL,
     DSpropAUTO_UPD,
     DSpropHIDDEN,
+    DSpropSEMI_HIDDEN,
     DSpropPERSONAL,
     DSpropNAME,
 
